@@ -11,6 +11,9 @@ rm -vrf magic_config/magic_config.egg-info
 
 python -m build
 
+twine check dist/* && python -m twine upload --verbose dist/*
+
+
 #python -m twine upload --verbose --repository testpypi dist/*
-python -m twine upload --verbose dist/* --skip-existing
+#python -m twine upload --verbose dist/*
 
