@@ -1,5 +1,4 @@
-import sys
-
+# import sys
 # if sys.version_info < (3, 10, 8):
 #     raise ImportError('Your Python version {0} is not supported by MagicConfig, please install '
 #                       'Python 3.10.8+'.format('.'.join(map(str, sys.version_info[:3]))))
@@ -11,5 +10,5 @@ __all__ = (
     "Config"
 )
 
-__version__ = '0.1.10'
+__version__ = '0.1.12'
 
